# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyvpp']

package_data = \
{'': ['*']}

install_requires = \
['deims>=3.1,<4.0',
 'geopandas>=0.12.2,<0.13.0',
 'hda>=1.13,<2.0',
 'pyproj>=3.4.1,<4.0.0',
 'rasterio>=1.3.6,<2.0.0',
 'requests>=2.28.2,<3.0.0']

setup_kwargs = {
    'name': 'pyvpp',
    'version': '0.1.4',
    'description': 'Python package to download phenological data from Wekeo (HR-VPP datsets from Sentinel 2)\x1b[D\x1b[',
    'long_description': '# PyVPP\n\nPython package to download data from the [Pan European High Resolution Vegetation Phenology and Productivity](https://land.copernicus.eu/pan-european/biophysical-parameters/high-resolution-vegetation-phenology-and-productivity) part of the Copernicus Land Monitoring Service ([CLMS](https://land.copernicus.eu/)). This package have been developed within the framework of the [eLTER H2020](https://elter-ri.eu/) and [SUMHAL](https://lifewatcheric-sumhal.csic.es/descripcion-del-proyecto/) projects, as  a  tool  aimed  at  scientists  and  managers  of  the  sites  integrated  in  the  eLTER  network,  for  which  long-term  phenology  monitoring  can  be  assessed. \n         \n![](https://i.imgur.com/Sv9LfYj.png)\n\n## What we use\nThe package is based in these magnificient python libraries:\n\n- [HDA python package](https://pypi.org/project/hda/) to download data from [Wekeo](https://www.wekeo.eu/). \n- [Deims](https://pypi.org/project/deims/) is a python package to get data from the Dynamic Ecological Information Management System - Site and dataset registry ([DEIMS-SDR](https://deims.org/)). We use this library to quickly get the spatial boundaries of the eLTER sites.\n- [PyProj](https://pypi.org/project/pyproj/), [Geopandas](https://pypi.org/project/geopandas/) and [Rasterio](https://pypi.org/project/rasterio/) are used (as always :blush:) to do the spatial parts related with getting extents, reprojecting, mosaicking and clipping.\n\n## What we do\n\nThe script accepts both as input, a shapefile or a deims id (**please remember to add "deimsid:yoursiteid" in case you use this option**), then it will read it as a Geodataframe, and it will download all the tiles that intersect the Bounding Box of the input boundaries. Once the tiles are downloaded it will mosaic them gruping by dates and products and it will crop the mosaics with the boundaries. Keeping in the ouptu folder (it will create a _/pyhda_ folder in your current working directory) just the "_mosaic_selectedvariable_rec.tif_" files. \n\nAt the moment we only offer 2 datasets of all those available in wekeo:\n\n1. ### **VPP_Index (Vegetation Indices): EO:EEA:DAT:CLMS_HRVPP_VI**\n\n![Vegetation Indices](https://i.imgur.com/t53cPMC.png)\n\n2. ### **VPP_Pheno (Phenology and Productivity): EO:EEA:DAT:CLMS_HRVPP_VPP**\n\n![Phenology](https://i.imgur.com/BaLKr5s.png)\n\n Just a little of the whole catalog offered in Wekeo (you can have a look [here](https://pn-csw.apps.mercator.dpi.wekeo.eu/elastic-csw/service?service=CSW&request=GetRecords&version=2.0.2&ElementSetName=summary&resultType=results&maxRecords=100)), but they are the only 2 that are interested for us in this project that is linked with Phenology. \n\n It\'s very likely that we will add more datasets in the near future. Even better, if you find this package interesting and want to add some more datasets, please fell free to do it (and maybe share that with us with a Pull Requests :wink:)\n\n## Why a package\n\nAs we said, this is intended to be used for eLTER sites managers and/or researchers, but it could be used to download data for any part of the globe (where data exists, of course). So we consider that this script could be useful for people moreover eLTER network. Besides, we think that have a python package to import it, is an approach more "friendly to use" than having a long script to copy and paste in different enviroments. \n\n## How to use it\n\nVery easy, just import the library, select your input shape or deims id site, select the dates and the variables and launch the process with .run(). The typical workflow, once installed, would be like that:\n\n```python\nimport pyvpp\n\n# Just replace the second parameter (deimsid for /path/to/yor/shapefile.shp) for your local shapefile in case you want to use a shape.\nMyWekeo = pyvpp.wekeo_download("VPP_Index", "deimsid:https://deims.org/bcbc866c-3f4f-47a8-bbbc-0a93df6de7b2", [\'2018-01-01\', \'2018-06-30\'], [\'LAI\', \'FAPAR\'])\nMyWekeo.run()\n```\nThe upper code will do the whole process for Doñana Long-Term Socio-ecological Research Platform (you can paste the link in a browser if you are curious) and just remain the LAI and FAPAR variables cropped with Doñana boundaries in the /pyhda folder. \nThere\'s also the possibility to keep the original Sentinel 2 tiles (this product are based in Sentinel 2 images, sorry, maybe I have should said this before) in your folder. \n\nIn that case you maybe want to run the process once by once, what can be done in the next way:\n\n```python\nimport pyvpp\n\nMyWekeo = pyvpp.wekeo_download("VPP_Index", "deimsid:https://deims.org/bcbc866c-3f4f-47a8-bbbc-0a93df6de7b2", [\'2018-01-01\', \'2018-06-30\'], [\'LAI\', \'FAPAR\'])\n# Do the download\nMyWekeo.download()\n# Do the mosaics and cropping\nMyWekeo.mosaic()\n# Cleaning folder of original tiles and whole mosaics\nMyWekeo.clean()\n```\n\nYou can find the list of variables availables in these 2 datasets in Wekeo, but we work with the 4 vegetation indices:\n\n 1. **PPI**, Plant Phenology Index\n 2. **NDVI**, Normalized Difference vegetation Index\n 3. **LAI**, Leaf Area Index,\n 4. **FAPAR**, Fraction of Absorbed Photosynthetically Active Radiation\n \n And just with these phenometrics (but you could download any of the availables, just be sure to type correctly their names):\n \n 1. **SOSD**, Start of the season Day of the Year\n 2. **SOSV**, Start of the season Value of Vegetation Index\n 3. **MAXD**, Maximun of the season Day of the Year\n 4. **MAXV**, Maximun of the season Value of Vegetation Index\n 5. **EOSD**, End of the season Day of the Year\n 6. **EOSV**, End of the season Value of the Vegetation Index\n\n ## Important info! (specially for **Datalab** users)\n\n The download from Wekeo needs a token generated taken into account a config file where yuour user and password are stored (please, read [this](https://www.wekeo.eu/docs/hda-python-lib)). If you are running this in your local PC, just cerate your .hdarc file with your personal info and forget about it. But, if you run this in the Datalab (This is just for eLTER users), maybe you don\'t feel comfortable with the idea of having your credentials stored in the Datalab. Plus, if you don\'t delete this file and someone runs the script, the data will be downloaded with your account. Not a big deal, but it better to solve that.\n\n So, we have add a couple of functions to fix this. _fillHda()_ and _delHdaInfo()_. These functions are imported when you import the script, so the only thing you need to do is this:\n \n```python\n# This will create or rewrite in case that it already exists, the .hdarc with your credentials in the home folder.\n# This should be the first thing that you do before run the WekeoDownload process\nfillHda("youruser", "yourpassword")\n```\n\n```python\n# And just be sure to run the del funciton when you are done. This will left the .hdarc but without any credentials in it, just white spaces waiting for the next fillHda() call.\n# This should be the last thing that you do before exit your datalab session.\ndelHdaInfo()  \n```\n\n## ToDo\n\nTo do for you: **Please, don\'t forget download and delete the Pyhda folder in case you are in the Datalab**. \n',
    'author': 'Diego García Díaz',
    'author_email': 'digd.geografo@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
